summaryrefslogtreecommitdiff
path: root/gcc/ggc-page.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/ggc-page.c')
-rw-r--r--gcc/ggc-page.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/ggc-page.c b/gcc/ggc-page.c
index f6fe8cdcd08..5063ccd18ba 100644
--- a/gcc/ggc-page.c
+++ b/gcc/ggc-page.c
@@ -853,8 +853,8 @@ adjust_depth (void)
{
top = G.by_depth[G.by_depth_in_use-1];
- /* Peel back indicies in depth that index into by_depth, so that
- as new elements are added to by_depth, we note the indicies
+ /* Peel back indices in depth that index into by_depth, so that
+ as new elements are added to by_depth, we note the indices
of those elements, if they are for new context depths. */
while (G.depth_in_use > (size_t)top->context_depth+1)
--G.depth_in_use;